def test_five_end(f1):

    result = f1.five_end(slack=5)

    print(f1)
    print(result)

    assert list(result.Start) == [0, 3, 2]
    assert list(result.End) == [9, 14, 13]


def test_three_end(f2):

    print(f2)

    result = f2.three_end(slack=500)

    print(result)

    assert list(result.Start) == [0, 0]
    assert list(result.End) == [503, 508]



import pandas as pd
from sorted_nearest import makewindows
from sorted_nearest import maketiles


def _windows(df, kwargs):

    window_size = kwargs["window_size"]

    strand = kwargs.get("strand", None)

    idxs, starts, ends = makewindows(df.index.values, df.Start.values,
                                     df.End.values, window_size)

    df = df.reindex(idxs)
    df.loc[:, "Start"] = starts
    df.loc[:, "End"] = ends

    return df


def _tiles(df, kwargs):

    window_size = kwargs["tile_size"]

    strand = kwargs.get("strand", None)

    idxs, starts, ends = maketiles(df.index.values, df.Start.values,
                                   df.End.values, window_size)

    df = df.reindex(idxs)
    df.loc[:, "Start"] = starts
    df.loc[:, "End"] = ends

    return df



import os
from distutils.core import setup
from setuptools import find_packages

__version__ = open("pyranges/version.py").readline().split(" = ")[1].replace(
    '"', '').strip()

install_requires = [
    "cython", "pandas", "ncls", "tabulate", "sorted_nearest", "pyrle",
    "natsort"] #,

# goptional_requires = ["bamread", "pybigwig", "ray"]

if os.getenv("TRAVIS"):
    install_requires.append("coveralls")

setup(
    name="pyranges",
    packages=find_packages(),
    package_data={
        'pyranges': [
            'example_data/*.bed', 'example_data/*.gtf', 'example_data/*.bam',
            'example_data/*.bam.bai'
        ]
    },
    # data_files = ["LICENSE"],
    include_dirs=["."],
    version=__version__,
    description="GenomicRanges for Python.",
    author="Endre Bakken Stovner",
    author_email="endrebak85@gmail.com",
    url="http://github.com/endrebak/pyranges",
    keywords=["Bioinformatics"],
    license="MIT",
    install_requires=install_requires,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Development Status :: 4 - Beta", "Environment :: Other Environment",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        'License :: OSI Approved :: MIT License',
        "Operating System :: POSIX :: Linux",
        "Operating System :: MacOS :: MacOS X",
        "Topic :: Scientific/Engineering"
    ],
    long_description=("Performant Pythonic GenomicRanges."))
